From 86a4b842c37b54f0157f9aabfc7cc08ea6bb1c03 Mon Sep 17 00:00:00 2001
From: Per Carlson <pelle@hemmop.com>
Date: Fri, 16 Mar 2012 11:12:04 +0100
Subject: [PATCH] License attribute from META file is array.

---
 lib/DhMakePerl/Command/Packaging.pm |   29 +++++++++++++++++++++++------
 1 files changed, 23 insertions(+), 6 deletions(-)

diff --git a/lib/DhMakePerl/Command/Packaging.pm b/lib/DhMakePerl/Command/Packaging.pm
index 596104b..442bf65 100644
--- a/lib/DhMakePerl/Command/Packaging.pm
+++ b/lib/DhMakePerl/Command/Packaging.pm
@@ -2,6 +2,7 @@ package DhMakePerl::Command::Packaging;
 
 use strict;
 use warnings;
+use feature 'switch';
 
 =head1 NAME
 
@@ -1062,13 +1063,29 @@ sub create_copyright {
         # mind that many licenses are not meant to be used as
         # templates (i.e. you must add the author name and some
         # information within the licensing text as such).
-        if (   $self->meta->{license} and $self->meta->{license} =~ /perl/i
-            or $mangle_cprt =~ /terms\s*as\s*Perl\s*itself/is )
-        {
-            $licenses{'GPL-1+'}   = 1;
-            $licenses{'Artistic'} = 1;
-        }
+        if ( $self->meta->{license} ) {
+	    foreach ( @{ $self->meta->{license} }) {
+	        given ($_) {
+		    when (/apache_2_0/) { $licenses{'Apache-2.0'} = 1; }
+		    when (/artistic_1/) { $licenses{'Artistic'} = 1; }
+		    when (/artistic_2/) { $licenses{'Artistic-2.0'} = 1; }
+		    # EU::MM and M::B converts the unversioned 'gpl' to gpl_1.
+		    # As a unversioned GPL means *any* GPL,I think it's safe to use GPL-1+ here
+		    when (/gpl_1/) { $licenses{'GPL-1+'} = 1; }
+
+		    when (/perl_5/) {
+		       $licenses{'GPL-1+'}   = 1;
+                       $licenses{'Artistic'} = 1;
+		    }
+		}
+	  }
+	}
         else {
+	    if ( $mangle_cprt =~ /terms\s*as\s*Perl\s*itself/is ) {
+              $licenses{'GPL-1+'}   = 1;
+              $licenses{'Artistic'} = 1;
+	    }
+
             if ( $mangle_cprt =~ /[^L]GPL/ ) {
                 if ( $mangle_cprt =~ /GPL.*version\s*1.*later\s+version/is ) {
                     $licenses{'GPL-1+'} = 1;
-- 
1.7.9.1

